@@ -35,9 +35,23 @@ from .models.vendor_assistant import (
     PaginationInfo,
     TokenPagination,
 )
-from .services.vendor import VendorService
+from .models.vendor_workflow import (
+    VendorWorkflowSetting,
+    VendorWorkflowSettingsResponse,
+    VendorWorkflow,
+    VendorWorkflowStatus,
+    VendorWorkflowsResponse,
+    VendorWorkflowAlias,
+    VendorWorkflowAliasesResponse,
+    VendorWorkflowInstallRequest,
+    VendorWorkflowInstallSummary,
+    VendorWorkflowInstallResponse,
+    VendorWorkflowUninstallResponse,
+)
+from .services.vendor_assistant import VendorAssistantService
+from .services.vendor_workflow import VendorWorkflowService
 
-__version__ = "0.2.9"
+__version__ = "0.2.10"
 __all__ = [
     "CodeMieClient",
     "VendorType",
@@ -55,5 +69,17 @@ __all__ = [
     "VendorAssistantUninstallResponse",
     "PaginationInfo",
     "TokenPagination",
-    "VendorService",
+    "VendorAssistantService",
+    "VendorWorkflowSetting",
+    "VendorWorkflowSettingsResponse",
+    "VendorWorkflow",
+    "VendorWorkflowStatus",
+    "VendorWorkflowsResponse",
+    "VendorWorkflowAlias",
+    "VendorWorkflowAliasesResponse",
+    "VendorWorkflowInstallRequest",
+    "VendorWorkflowInstallSummary",
+    "VendorWorkflowInstallResponse",
+    "VendorWorkflowUninstallResponse",
+    "VendorWorkflowService",
 ]
